@@ -40,6 +40,8 @@
 #include <libgnomecanvas/gnome-canvas-pixbuf.h>
 #include <libgnomevfs/gnome-vfs.h>
 #include <libgnome/libgnometypebuiltins.h>
+#include <gconf/gconf-client.h>
+
 
 #include <libxml/tree.h>
 #include <libxml/parser.h>
@@ -69,6 +71,8 @@ const gchar *crash_type[] = {
 PoptData popt_data;
 
 DruidData druid_data;
+GConfClient *conf_client;
+
 
 static const struct poptOption options[] = {
 	{ "name",        0, POPT_ARG_STRING, &popt_data.name,         0, N_("Name of contact"),                    N_("NAME") },
@@ -247,7 +251,6 @@ on_gdb_save_clicked (GtkWidget *w, gpointer data)
 						   GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 						   GTK_STOCK_SAVE, GTK_RESPONSE_OK,
 						   NULL);
-	gtk_window_set_default_size (GTK_WINDOW (filechooser), 600, 400);
  run_save_dialog:
 	response = gtk_dialog_run (GTK_DIALOG (filechooser));
 	if (response == GTK_RESPONSE_OK) {
@@ -288,22 +291,13 @@ on_gdb_save_clicked (GtkWidget *w, gpointer data)
 }
 
 void
-on_product_toggle_clicked (GtkWidget *w, gpointer data)
+on_applications_products_changed (GtkWidget *w, gpointer data)
 {
-	char *button;
 
 	g_return_if_fail (druid_data.state == STATE_PRODUCT);
 
 	druid_data.show_products = !druid_data.show_products;
 
-	if (druid_data.show_products) {
-		button = _("Show _Applications");
-	} else {
-		button = _("Show _Products");
-	}
-
-	buddy_set_text ("product-toggle",    button);
-
 	products_list_load ();
 }
 
@@ -492,7 +486,9 @@ init_ui (void)
 	
 	glade_xml_signal_autoconnect (druid_data.xml);
 
-	load_config ();
+	init_gconf_stuff ();
+
+	druid_data.show_products = FALSE;
 
 	/* gtk_widget_set_default_direction (GTK_TEXT_DIR_RTL); */
 
@@ -602,46 +598,15 @@ init_ui (void)
 
 
 
-}
-
-GtkWidget *
-make_image (char *widget_name, char *icon, char *s2, int stock, int i2)
-{
-	GtkWidget *w = NULL;
-
-	if (stock) {
-		GtkIconSize size = GTK_ICON_SIZE_BUTTON;
-
-		if (s2)
-			size = glade_enum_from_string (GTK_TYPE_ICON_SIZE, s2);
-
-		w = gtk_image_new_from_stock (icon, size);
-	} else {
-		GnomeFileDomain domain = GNOME_FILE_DOMAIN_APP_PIXMAP;
-		char *filename;
-		
-		if (s2)
-			domain = glade_enum_from_string (GNOME_TYPE_FILE_DOMAIN, s2);
-
-		filename = gnome_program_locate_file (NULL, domain, icon, TRUE, NULL);
-
-		if (filename)
-			w = gtk_image_new_from_file (filename);
-		else
-			g_warning (_("Could not find pixmap: %s (%d)\n"), icon, domain);
-		g_free (filename);
-	}
-
-	if (w)
-		gtk_widget_show (w);
-
-	return w;
 }
 
 gint
 delete_me (GtkWidget *w, GdkEventAny *evt, gpointer data)
 {
-	save_config ();
+	if (druid_data.last_update_check > 0) {
+                gconf_client_set_int (conf_client, "/apps/bug-buddy/last_update_check",
+				      time(NULL), NULL);
+	}
 	gtk_main_quit ();
 	return FALSE;
 }
@@ -657,6 +622,7 @@ int
 main (int argc, char *argv[])
 {
 	GtkWidget *w;
+	GtkIconInfo *icon_info;
 	char *s;
 		
 	memset (&druid_data, 0, sizeof (druid_data));
@@ -676,12 +642,12 @@ main (int argc, char *argv[])
 			    GNOME_PARAM_APP_DATADIR, REAL_DATADIR,
 			    NULL);
 
-	s = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_PIXMAP, 
-				       "bug-buddy.png", TRUE, NULL);
-	
-	if (s)
-		gnome_window_icon_set_default_from_file (s);
-	g_free (s);
+	icon_info = gtk_icon_theme_lookup_icon (gtk_icon_theme_get_default (),
+						"bug-buddy", 48, 0);
+	if (icon_info) {
+		gnome_window_icon_set_default_from_file (gtk_icon_info_get_filename (icon_info));
+		gtk_icon_info_free (icon_info);
+        }
 
 	s = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_DATADIR,
 				       "bug-buddy/bug-buddy.glade", TRUE, NULL);
