@@ -308,9 +308,9 @@ get_trace_from_pair (const gchar *app, const gchar *extra)
 		short_app = strrchr (app, G_DIR_SEPARATOR) + 1;
 	} else {
 		long_app = g_find_program_in_path (app);
-		if (!long_app) {
+		if (!long_app && g_getenv("GNOME2_PATH")) {
 			/* Applets are not in path... */
-			long_app = g_strconcat(g_getenv("GNOME_PATH"), "/libexec/", app);
+			long_app = g_strconcat(g_getenv("GNOME2_PATH"), "/libexec/", app, NULL);
 		}
 		short_app = app;
 	}	
